@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -25,6 +25,7 @@ import ssl
 import hashlib
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.datavars import DataVars
+from calculate.lib.utils.files import readFile
 from sudsds.client import Client
 from cert_verify import verify, get_CRL
 
@@ -116,7 +117,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
         for cert in list_ca_certs:
             system_ca_db = clVarsCore.Get('cl_glob_root_cert')
             if os.path.exists(system_ca_db):
-                if cert in open(system_ca_db, 'r').read():
+                if cert in readFile(system_ca_db):
                     continue
 
             clVars = DataVars()
@@ -126,7 +127,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             user_root_cert = clVarsCore.Get('cl_user_root_cert')
             user_root_cert = user_root_cert.replace("~", homePath)
             if os.path.exists(user_root_cert):
-                if cert in open(user_root_cert, 'r').read():
+                if cert in readFile(user_root_cert):
                     continue
 
             cl_client_cert_dir = clVarsCore.Get('cl_client_cert_dir')
